|Build Status| |Docs|

.. |Build Status| image:: https://travis-ci.org/theislab/anndata.svg?branch=master
   :target: https://travis-ci.org/theislab/anndata
.. |Docs| image:: https://readthedocs.org/projects/scanpy/badge/?version=latest
   :target: https://scanpy.readthedocs.io

AnnData
=======

``anndata.AnnData`` stores a data matrix ``.X`` as an array or sparse matrix, annotation of samples ``.smp`` and variables ``.var`` as dataframes and unstructured annotation ``.uns`` as dictionary.

Read the `documentation <http://scanpy.readthedocs.io/api/scanpy.api.AnnData.html>`_.
